@@ -1,6 +1,6 @@
 ICA.BinBin <- function(pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1, Monotonicity=c("General"), 
-                       Sum_Pi_f = seq(from=0.01, to=0.99, by=.01), M=10000, Seed=sample(1:100000, size=1)) {   
-  
+                       Sum_Pi_f = seq(from=0.01, to=0.99, by=.01), M=10000, Volume.Perc=0, Seed=sample(1:100000, size=1)) {   
+
   Seed.orig <- Seed
   aantal <- length(Sum_Pi_f)*M 
   set.seed(Seed.orig)
@@ -13,23 +13,40 @@ ICA.BinBin <- function(pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1, Monotonic
   
   if (Monotonicity=="General"){
     
-    T_No <- ICA.BinBin(pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1, Seed=Seed.orig, Monotonicity=c("No"), Sum_Pi_f, M)
+    try(T_No <- ICA.BinBin(pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1, Seed=Seed.orig, Monotonicity=c("No"), Sum_Pi_f, M, Volume.Perc), silent=TRUE)
     sum_pi_f <- Pi.Vectors <- pi_f_all <- pi_r_all <- C3_all <- R2_H_all <- theta_T_all <- theta_S_all <- H_Delta_T_all <- pi_all <- NULL
-    T_True <- ICA.BinBin(pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1, Seed=Seed.orig, Monotonicity=c("True.Endp"), Sum_Pi_f, M)
+    try(T_True <- ICA.BinBin(pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1, Seed=Seed.orig, Monotonicity=c("True.Endp"), Sum_Pi_f, M, Volume.Perc), silent=TRUE)
     sum_pi_f <- Pi.Vectors <- pi_f_all <- pi_r_all <- C3_all <- R2_H_all <- theta_T_all <- theta_S_all <- H_Delta_T_all <- pi_all <- NULL
-    T_Surr <- ICA.BinBin(pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1, Seed=Seed.orig, Monotonicity=c("Surr.Endp"), Sum_Pi_f, M)
+    try(T_Surr <- ICA.BinBin(pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1, Seed=Seed.orig, Monotonicity=c("Surr.Endp"), Sum_Pi_f, M, Volume.Perc), silent=TRUE)
     sum_pi_f <- Pi.Vectors <- pi_f_all <- pi_r_all <- C3_all <- R2_H_all <- theta_T_all <- theta_S_all <- H_Delta_T_all <- pi_all <- NULL
-    T_SurrTrue <- ICA.BinBin(pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1, Seed=Seed.orig, Monotonicity=c("Surr.True.Endp"), Sum_Pi_f, M)
+    try(T_SurrTrue <- ICA.BinBin(pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1, Seed=Seed.orig, Monotonicity=c("Surr.True.Endp"), Sum_Pi_f, M, Volume.Perc), silent=TRUE)
     sum_pi_f <- Pi.Vectors <- pi_f_all <- pi_r_all <- C3_all <- R2_H_all <- theta_T_all <- theta_S_all <- H_Delta_T_all <- pi_all <- NULL
     
-    try(Pi.Vectors.No <- cbind(T_No$Pi.Vectors, "No"), silent=TRUE)
-    try(Pi.Vectors.T <- cbind(T_True$Pi.Vectors[,1:5], 0, 0, 0, T_True$Pi.Vectors[,6:7], 0, T_True$Pi.Vectors[,8:13], "True"), silent=TRUE)
-    try(Pi.Vectors.S <- cbind(T_Surr$Pi.Vectors[,1:2], 0, T_Surr$Pi.Vectors[,3:5], 0, T_Surr$Pi.Vectors[,8], 0, T_Surr$Pi.Vectors[,9],
+     if (exists("T_No")==TRUE){
+      if (!is.null(T_No)){Pi.Vectors.No <- cbind(T_No$Pi.Vectors, "No")}  } 
+        
+    if (exists("T_True")==TRUE){ 
+      if (!is.null(T_True)){Pi.Vectors.T <- cbind(T_True$Pi.Vectors[,1:5], 0, 0, 0, T_True$Pi.Vectors[,6:7], 0, T_True$Pi.Vectors[,8:13], "True")}
+    }
+      
+    if (exists("T_Surr")==TRUE){ 
+      if (!is.null(T_Surr)){Pi.Vectors.S <- cbind(T_Surr$Pi.Vectors[,1:2], 0, T_Surr$Pi.Vectors[,3:5], 0, T_Surr$Pi.Vectors[,8], 0, T_Surr$Pi.Vectors[,9],
                               T_Surr$Pi.Vectors[,6], T_Surr$Pi.Vectors[,10], 0, T_Surr$Pi.Vectors[,7], 
-                              T_Surr$Pi.Vectors[,11:13], "Surr"), silent=TRUE)
-    try(Pi.Vectors.ST <- cbind(T_SurrTrue$Pi.Vectors[,1:2], 0, T_SurrTrue$Pi.Vectors[,3:4], 0, 0, 0, 0, T_SurrTrue$Pi.Vectors[,5], 0,
-                               T_SurrTrue$Pi.Vectors[,6], 0, T_SurrTrue$Pi.Vectors[,7:10], "SurrTrue"), silent=TRUE)
+                              T_Surr$Pi.Vectors[,11:13], "Surr")}  }
     
+    if (exists("T_SurrTrue")==TRUE){
+      if (!is.null(T_SurrTrue)){Pi.Vectors.ST <- cbind(T_SurrTrue$Pi.Vectors[,1:2], 0, T_SurrTrue$Pi.Vectors[,3:4], 0, 0, 0, 0, T_SurrTrue$Pi.Vectors[,5], 0,
+                               T_SurrTrue$Pi.Vectors[,6], 0, T_SurrTrue$Pi.Vectors[,7:10], "SurrTrue")}   }
+    
+    if (exists("Pi.Vectors.No")==FALSE) {Pi.Vectors.No <-  matrix(rep(NA, times=18), nrow = 1)} 
+    if (dim(Pi.Vectors.No)[2]<18) {Pi.Vectors.No <-  matrix(rep(NA, times=18), nrow = 1)} 
+    if (exists("Pi.Vectors.S")==FALSE) {Pi.Vectors.S <-  matrix(rep(NA, times=18), nrow = 1)} 
+    if (dim(Pi.Vectors.S)[2]<18) {Pi.Vectors.S <-  matrix(rep(NA, times=18), nrow = 1)} 
+    if (exists("Pi.Vectors.T")==FALSE) {Pi.Vectors.T <-  matrix(rep(NA, times=18), nrow = 1)} 
+    if (dim(Pi.Vectors.T)[2]<18) {Pi.Vectors.T <-  matrix(rep(NA, times=18), nrow = 1)} 
+    if (exists("Pi.Vectors.ST")==FALSE) {Pi.Vectors.ST <-  matrix(rep(NA, times=18), nrow = 1)} 
+    if (dim(Pi.Vectors.ST)[2]<18) {Pi.Vectors.ST <-  matrix(rep(NA, times=18), nrow = 1)} 
+   
     try(colnames(Pi.Vectors.No) <- colnames(Pi.Vectors.T) <-  colnames(Pi.Vectors.S) <- colnames(Pi.Vectors.ST) <- 
           c("Pi_0000", "Pi_0100", "Pi_0010", "Pi_0001", "Pi_0101", "Pi_1000", "Pi_1010", "Pi_1001", "Pi_1110", "Pi_1101", "Pi_1011", 
             "Pi_1111", "Pi_0110", "Pi_0011", "Pi_0111", "Pi_1100", "Sum.Pi.f", "Monotonicity"), silent=TRUE) 
@@ -39,12 +56,26 @@ ICA.BinBin <- function(pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1, Monotonic
     if (exists("Pi.Vectors.S")==FALSE){Pi.Vectors.S <- NULL}
     if (exists("Pi.Vectors.ST")==FALSE){Pi.Vectors.ST <- NULL}
     
-    try(Pi.Vectors <- rbind(Pi.Vectors.No, Pi.Vectors.T, Pi.Vectors.S, Pi.Vectors.ST), silent=TRUE)
-    C3_all <- c(T_No$C3, T_True$C3, T_Surr$C3, T_SurrTrue$C3)
-    R2_H_all  <- c(T_No$R2_H, T_True$R2_H, T_Surr$R2_H, T_SurrTrue$R2_H)
-    theta_T_all <- c(T_No$Theta_T, T_True$Theta_T, T_Surr$Theta_T, T_SurrTrue$Theta_T)
-    theta_S_all <- c(T_No$Theta_S, T_True$Theta_S, T_Surr$Theta_S, T_SurrTrue$Theta_S)
-    H_Delta_T_all <- c(T_No$H_Delta_T, T_True$H_Delta_T, T_Surr$H_Delta_T, T_SurrTrue$H_Delta_T)  
+    try(Pi.Vectors <- na.exclude(rbind(Pi.Vectors.No, Pi.Vectors.T, Pi.Vectors.S, Pi.Vectors.ST)), silent=TRUE)
+    
+    if ((exists("T_No"))==FALSE){T_No = NULL
+                                 T_No$C3 <- T_No$R2_H <- T_No$Theta_T <- T_No$Theta_S <-  T_No$H_Delta_T <- NA}
+    
+    if ((exists("T_True"))==FALSE){T_True = NULL
+                                   T_True$C3 <- T_True$R2_H <- T_True$Theta_T <- T_True$Theta_S <-  T_True$H_Delta_T <- NA}
+    
+    if ((exists("T_Surr"))==FALSE){T_Surr = NULL
+                                   T_Surr$C3 <- T_Surr$R2_H <- T_Surr$Theta_T <- T_Surr$Theta_S <-  T_Surr$H_Delta_T <- NA}
+    
+    if ((exists("T_SurrTrue"))==FALSE){T_SurrTrue = NULL
+                                       T_SurrTrue$C3 <- T_SurrTrue$R2_H <- T_SurrTrue$Theta_T <- T_SurrTrue$Theta_S <-  T_SurrTrue$H_Delta_T <- NA}
+    
+    
+    C3_all <- as.numeric(na.exclude(c(T_No$C3, T_True$C3, T_Surr$C3, T_SurrTrue$C3)))
+    R2_H_all  <- as.numeric(na.exclude(c(T_No$R2_H, T_True$R2_H, T_Surr$R2_H, T_SurrTrue$R2_H)))
+    theta_T_all <- as.numeric(na.exclude(c(T_No$Theta_T, T_True$Theta_T, T_Surr$Theta_T, T_SurrTrue$Theta_T)))
+    theta_S_all <- as.numeric(na.exclude(c(T_No$Theta_S, T_True$Theta_S, T_Surr$Theta_S, T_SurrTrue$Theta_S)))
+    H_Delta_T_all <- as.numeric(na.exclude(c(T_No$H_Delta_T, T_True$H_Delta_T, T_Surr$H_Delta_T, T_SurrTrue$H_Delta_T))) 
     
   }
   
@@ -68,7 +99,6 @@ ICA.BinBin <- function(pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1, Monotonic
                          1, 0, 1, 0, 1, 0, 0), ncol=9)
     A <- cbind(A_r, A_f)
     
-    
     #restrictions
     min_pi_1001 <- min(pi1_0_, pi_0_1)
     min_pi_1110 <- min(pi1_1_, pi_1_0)
@@ -80,6 +110,31 @@ ICA.BinBin <- function(pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1, Monotonic
     min_pi_0111 <- min(pi0_1_, pi_1_1)
     min_pi_1100 <- min(pi1_0_, pi_1_0)
     
+    pi_1 <- seq(0, min_pi_1001, by=.01)
+    pi_2 <- seq(0, min_pi_1110, by=.01) 
+    pi_3 <- seq(0, min_pi_1101, by=.01) 
+    pi_4 <- seq(0, min_pi_1011, by=.01) 
+    pi_5 <- seq(0, min_pi_1111, by=.01) 
+    pi_6 <- seq(0, min_pi_0110, by=.01) 
+    pi_7 <- seq(0, min_pi_0011, by=.01) 
+    pi_8 <- seq(0, min_pi_0111, by=.01) 
+    pi_9 <- seq(0, min_pi_1100, by=.01) 
+    
+      tot_combn_No <- 
+        as.numeric(length(pi_1))*as.numeric(length(pi_2))*as.numeric(length(pi_3))*as.numeric(length(pi_4))*
+        as.numeric(length(pi_5))*as.numeric(length(pi_6))*as.numeric(length(pi_7))*as.numeric(length(pi_8))*as.numeric(length(pi_9))
+    
+    #if (Volume.Perc==0){
+    #Seed <- round(runif(min=(1+tot_combn_No), max=2147483647, n=1), digits=0)
+    #}
+    
+    if (Volume.Perc != 0){M <- tot_combn_No * Volume.Perc}
+    
+    if (Volume.Perc != 0 & M > 1000000){
+      cat("\nNote. A total of ", M, " runs will be conducted. This may require a long time. \n")
+      cat("Consider using a lower Volume.Perc value or use the M= argument instead of Volume.Perc.\n")
+    }
+    
     max_val <- min((min_pi_1001 + min_pi_1110 + min_pi_1101 + min_pi_1011 + min_pi_1111 + 
       min_pi_0110 + min_pi_0011 + min_pi_0111 + min_pi_1100), 1)
     min_val <- min(Sum_Pi_f)
@@ -89,17 +144,22 @@ ICA.BinBin <- function(pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1, Monotonic
     Sum_Pi_f_number <- length(Sum_Pi_f)
     
     for (k in 1: Sum_Pi_f_number){
-      
+           
       for (i in 1: M){
 
+#        if (Volume.Perc==0){Seed <- Seed-1}
+#        if (Volume.Perc!=0){Seed <- Seed+1}
+#        set.seed(Seed)
+ 
         Seed <- Seed-1   
         set.seed(Seed)
         
+        
         pi_f <- (RandVec(a=0, b=Sum_Pi_f[k], s=Sum_Pi_f[k], n=9, 1, Seed=Seed))$RandVecOutput  
         
         pi_r <- solve(A_r) %*% (vector_b - (A_f %*% pi_f))
         
-        if ((sum(pi_r >= -0.00000001 & pi_r <= 1.00000001) == 7)==TRUE) {
+        if ((sum(pi_r >= 0 & pi_r <= 1) == 7)==TRUE) {
           
           for (l in 1: length(pi_r)){
             if (pi_r[l] < 0) {pi_r[l] <- c(0)}
@@ -121,7 +181,15 @@ ICA.BinBin <- function(pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1, Monotonic
           Delta_c_mat <-
             matrix(data=c(mat1, mat2, mat3, mat4, mat5, mat6, mat7, mat8, mat9), nrow=3)
           
-          C3 <- 1
+          #C3
+          pi_a <- mat1+mat5+mat9
+          pi_e <- ((mat1+mat4+mat7)*(mat1+mat2+mat3))+((mat2+mat5+mat8)*(mat4+mat5+mat6))+((mat3+mat6+mat9)*(mat7+mat8+mat9))
+          kappa <- (pi_a - pi_e)/(1-pi_e)
+          pi_max <- 
+            min(mat1+mat4+mat7, mat1+mat2+mat3) + min(mat2+mat5+mat8, mat4+mat5+mat6) + min(mat3+mat6+mat9, mat7+mat8+mat9)
+          k_max <- (pi_max - pi_e)/(1-pi_e)
+          C3 <- (pi_a - pi_e) / (pi_max - pi_e)
+          
           C3_all <- cbind(C3_all, C3)
           
           #R2_H
@@ -212,6 +280,25 @@ ICA.BinBin <- function(pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1, Monotonic
     min_pi_0111 <- min(pi0_1_, pi_1_1)
     min_pi_1100 <- min(pi1_0_, pi_1_0)
     
+    pi_1 <- seq(0, min_pi_1111, by=.01) 
+    pi_2 <- seq(0, min_pi_0110, by=.01) 
+    pi_3 <- seq(0, min_pi_0011, by=.01) 
+    pi_4 <- seq(0, min_pi_0111, by=.01) 
+    pi_5 <- seq(0, min_pi_1100, by=.01) 
+    
+      tot_combn_T <- 
+        as.numeric(length(pi_1))*as.numeric(length(pi_2))*as.numeric(length(pi_3))*as.numeric(length(pi_4))*
+        as.numeric(length(pi_5))
+    #if (Volume.Perc==0){
+    #Seed <- round(runif(min=(1+tot_combn_T), max=2147483647, n=1), digits=0)}
+    
+    if (Volume.Perc != 0){M <- tot_combn_T * Volume.Perc}
+    
+    if (Volume.Perc != 0 & M > 1000000){
+      cat("\nNote. A total of ", tot_combn_T, " runs will be conducted. This may require a long time. \n")
+      cat("Consider using a lower Volume.Perc value or use the M= argument instead of Volume.Perc.\n")
+    }
+    
     max_val <- min((min_pi_1111 + min_pi_0110 + min_pi_0011 + min_pi_0111 + min_pi_1100), 1)
     min_val <- min(Sum_Pi_f)
     by_val = (max(Sum_Pi_f)-min(Sum_Pi_f))/(length(Sum_Pi_f)-1)
@@ -223,16 +310,20 @@ ICA.BinBin <- function(pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1, Monotonic
     for (k in 1: Sum_Pi_f_number){
       
       for (i in 1: M){
-        
+#       if (Volume.Perc==0){Seed <- Seed-1}
+#        if (Volume.Perc!=0){Seed <- Seed+1}   
+#        set.seed(Seed)
+
         Seed <- Seed-1   
         set.seed(Seed)
         
+        
         pi_f <- (RandVec(a=0, b=Sum_Pi_f[k], s=Sum_Pi_f[k], n=5, 1, Seed=Seed))$RandVecOutput  
         
         pi_r <-   
           solve(A_star_r) %*% (vector_b - (A_star_f %*% pi_f))
         
-        if ((sum(pi_r >= -0.00000001 & pi_r <= 1.00000001) == 7)==TRUE) {
+        if ((sum(pi_r >= 0 & pi_r <= 1) == 7)==TRUE) {
           
           for (l in 1: length(pi_r)){
             if (pi_r[l] < 0) {pi_r[l] <- c(0)}
@@ -254,7 +345,14 @@ ICA.BinBin <- function(pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1, Monotonic
           Delta_c_mat <-
             matrix(data=c(mat1, mat2, mat3, mat4, mat5, mat6, mat7, mat8, mat9), nrow=3)
           
-          C3 <- 1
+          #C3
+          pi_a <- mat1+mat5+mat9
+          pi_e <- ((mat1+mat4+mat7)*(mat1+mat2+mat3))+((mat2+mat5+mat8)*(mat4+mat5+mat6))+((mat3+mat6+mat9)*(mat7+mat8+mat9))
+          kappa <- (pi_a - pi_e)/(1-pi_e)
+          pi_max <- 
+            min(mat1+mat4+mat7, mat1+mat2+mat3) + min(mat2+mat5+mat8, mat4+mat5+mat6) + min(mat3+mat6+mat9, mat7+mat8+mat9)
+          k_max <- (pi_max - pi_e)/(1-pi_e)
+          C3 <- (pi_a - pi_e) / (pi_max - pi_e)
           C3_all <- cbind(C3_all, C3)
           
           #R2_H
@@ -306,7 +404,7 @@ ICA.BinBin <- function(pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1, Monotonic
     num <- dim(R2_H_all)[2]
     
     
-    if (is.null(num)==TRUE){stop(c("No pi vectors found that are in line with the restrictions based on the data."))}
+   if (is.null(num)==TRUE){stop(c("No pi vectors found that are in line with the restrictions based on the data."))}
     
     sum_pi_f <- colSums(pi_all[8:12,]) 
     Pi.Vectors <- 
@@ -342,6 +440,25 @@ ICA.BinBin <- function(pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1, Monotonic
     min_pi_0111 <- min(pi0_1_, pi_1_1)
     min_pi_1100 <- min(pi1_0_, pi_1_0)
     
+    pi_1 <- seq(0, min_pi_1001, by=.01)
+    pi_2 <- seq(0, min_pi_1101, by=.01) 
+    pi_3 <- seq(0, min_pi_1111, by=.01) 
+    pi_4 <- seq(0, min_pi_0111, by=.01) 
+    pi_5 <- seq(0, min_pi_1100, by=.01) 
+    
+      tot_combn_S <- 
+        as.numeric(length(pi_1))*as.numeric(length(pi_2))*as.numeric(length(pi_3))*as.numeric(length(pi_4))*
+        as.numeric(length(pi_5))
+    #if (Volume.Perc==0){
+    #Seed <- round(runif(min=(1+tot_combn_S), max=2147483647, n=1), digits=0)}
+    
+    if (Volume.Perc != 0){M <- tot_combn_S * Volume.Perc}
+    
+    if (Volume.Perc != 0 & M > 1000000){
+      cat("\nNote. A total of ", tot_combn_S, " runs will be conducted. This may require a long time. \n")
+      cat("Consider using a lower Volume.Perc value or use the M= argument instead of Volume.Perc.\n")
+    }
+    
     max_val <- min((min_pi_1001 + min_pi_1101 + min_pi_1111 + min_pi_0111 + min_pi_1100), 1)
     min_val <- min(Sum_Pi_f)
     by_val = (max(Sum_Pi_f)-min(Sum_Pi_f))/(length(Sum_Pi_f)-1)
@@ -354,6 +471,10 @@ ICA.BinBin <- function(pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1, Monotonic
       
       for (i in 1: M){
         
+#        if (Volume.Perc==0){Seed <- Seed-1}
+#        if (Volume.Perc!=0){Seed <- Seed+1}
+#        set.seed(Seed)
+ 
         Seed <- Seed-1  
         set.seed(Seed)
         
@@ -361,7 +482,7 @@ ICA.BinBin <- function(pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1, Monotonic
         
         pi_r <- solve(A_star_r) %*% (vector_b - (A_star_f %*% pi_f))
         
-        if ((sum(pi_r >= -0.00000001 & pi_r <= 1.00000001) == 7)==TRUE) {
+        if ((sum(pi_r >= 0 & pi_r <= 1) == 7)==TRUE) {
           
           for (l in 1: length(pi_r)){
             if (pi_r[l] < 0) {pi_r[l] <- c(0)}
@@ -384,7 +505,14 @@ ICA.BinBin <- function(pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1, Monotonic
           Delta_c_mat <-
             matrix(data=c(mat1, mat2, mat3, mat4, mat5, mat6, mat7, mat8, mat9), nrow=3)
           
-          C3 <- 1
+          #C3
+          pi_a <- mat1+mat5+mat9
+          pi_e <- ((mat1+mat4+mat7)*(mat1+mat2+mat3))+((mat2+mat5+mat8)*(mat4+mat5+mat6))+((mat3+mat6+mat9)*(mat7+mat8+mat9))
+          kappa <- (pi_a - pi_e)/(1-pi_e)
+          pi_max <- 
+            min(mat1+mat4+mat7, mat1+mat2+mat3) + min(mat2+mat5+mat8, mat4+mat5+mat6) + min(mat3+mat6+mat9, mat7+mat8+mat9)
+          k_max <- (pi_max - pi_e)/(1-pi_e)
+          C3 <- (pi_a - pi_e) / (pi_max - pi_e)
           C3_all <- cbind(C3_all, C3)
           
           #R2_H
@@ -468,6 +596,16 @@ ICA.BinBin <- function(pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1, Monotonic
     min_pi_0111 <- min(pi0_1_, pi_1_1)
     min_pi_1100 <- min(pi1_0_, pi_1_0)
     
+    pi_1 <- seq(0, min_pi_0111, by=.01) 
+    pi_2 <- seq(0, min_pi_1100, by=.01) 
+    
+      tot_combn_ST <- 
+        as.numeric(length(pi_1))*as.numeric(length(pi_2))
+      
+    #if (Volume.Perc==0){Seed <- round(runif(min=(1+tot_combn_ST), max=2147483647, n=1), digits=0)}
+
+    if (Volume.Perc != 0){M <- tot_combn_ST * Volume.Perc}
+    
     max_val <- min((min_pi_0111 + min_pi_1100), 1)
     min_val <- min(Sum_Pi_f)
     by_val = (max(Sum_Pi_f)-min(Sum_Pi_f))/(length(Sum_Pi_f)-1)
@@ -479,15 +617,20 @@ ICA.BinBin <- function(pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1, Monotonic
       
       for (i in 1: M){
         
-        Seed <- Seed-1   
+#        if (Volume.Perc==0){Seed <- Seed-1}
+#        if (Volume.Perc!=0){Seed <- Seed+1}
+#        set.seed(Seed)
+
+        Seed <- Seed-1  
         set.seed(Seed)
         
+        
         pi_f <- (RandVec(a=0, b=Sum_Pi_f[k], s=Sum_Pi_f[k], n=2, 1, Seed=Seed))$RandVecOutput  
         
         pi_r <-   
           solve(A_star_r) %*% (vector_b - (A_star_f %*% pi_f))
         
-        if ((sum(pi_r >= -0.00000001 & pi_r <= 1.00000001) == 7)==TRUE) {
+        if ((sum(pi_r >= 0 & pi_r <= 1) == 7)==TRUE) {
           
           for (l in 1: length(pi_r)){
             if (pi_r[l] < 0) {pi_r[l] <- c(0)}
@@ -509,7 +652,14 @@ ICA.BinBin <- function(pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1, Monotonic
           Delta_c_mat <-
             matrix(data=c(mat1, mat2, mat3, mat4, mat5, mat6, mat7, mat8, mat9), nrow=3)
           
-          C3 <- 1
+          #C3
+          pi_a <- mat1+mat5+mat9
+          pi_e <- ((mat1+mat4+mat7)*(mat1+mat2+mat3))+((mat2+mat5+mat8)*(mat4+mat5+mat6))+((mat3+mat6+mat9)*(mat7+mat8+mat9))
+          kappa <- (pi_a - pi_e)/(1-pi_e)
+          pi_max <- 
+            min(mat1+mat4+mat7, mat1+mat2+mat3) + min(mat2+mat5+mat8, mat4+mat5+mat6) + min(mat3+mat6+mat9, mat7+mat8+mat9)
+          k_max <- (pi_max - pi_e)/(1-pi_e)
+          C3 <- (pi_a - pi_e) / (pi_max - pi_e)
           C3_all <- cbind(C3_all, C3)
           
           #R2_H
@@ -560,7 +710,7 @@ ICA.BinBin <- function(pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1, Monotonic
     num <- dim(R2_H_all)[2]
     
     
-      if (is.null(num)==TRUE){stop(c("No pi vectors found that are in line with the restrictions based on the data."))}
+     if (is.null(num)==TRUE){stop(c("No pi vectors found that are in line with the restrictions based on the data."))}
   
         
     sum_pi_f <- colSums(pi_all[8:9,]) 
@@ -571,10 +721,15 @@ ICA.BinBin <- function(pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1, Monotonic
         
   } # end mono S and T
   
+ if (exists("tot_combn_No")==FALSE){tot_combn_No <- c(0)}
+ if (exists("tot_combn_S")==FALSE){tot_combn_S <- c(0)}
+ if (exists("tot_combn_T")==FALSE){tot_combn_T <- c(0)}
+ if (exists("tot_combn_ST")==FALSE){tot_combn_ST <- c(0)}
+  
   fit <- 
     list(Pi.Vectors= Pi.Vectors, R2_H=as.numeric(R2_H_all), Theta_T = as.numeric(theta_T_all), 
-         Theta_S = as.numeric(theta_S_all), H_Delta_T = as.numeric(H_Delta_T_all), 
-         Monotonicity=Monotonicity, Call=match.call())      
+         Theta_S = as.numeric(theta_S_all), H_Delta_T = as.numeric(H_Delta_T_all), Monotonicity=Monotonicity, 
+         Volume.No=tot_combn_No, Volume.T=tot_combn_T, Volume.S=tot_combn_S, Volume.ST=tot_combn_ST, Call=match.call())      
   
   class(fit) <- "ICA.BinBin"
   fit
